Normalizing flow for generating lattice field configurations (Lattice QCD, ETHZ/CSIC)
=====================================================================================

The code is adapted from `this notebook <https://github.com/jkomijani/normflow_>`_ from the Lattice QCD use case.

More information on the use case is available in the published deliverables,
`D4.2 <https://zenodo.org/records/10417138>`_,
`D7.2 <https://zenodo.org/records/10417161>`_ and `D7.4 <https://zenodo.org/records/10224277>`_.


About the use-case and integration
----------------------------------
.. include:: ../../use-cases/lattice-qcd/README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- sphinx-start -->
   :end-before: <!-- sphinx-end -->
